/**
 * Copyright (c) 2008 appspy.org, Contributors.
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 *
 * You may obtain a copy of the License at 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the 
 * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language governing permissions 
 * and limitations under the License. */
package org.appspy.admin.jobs;

import javax.persistence.EntityManagerFactory;

import org.quartz.JobExecutionContext;
import org.springframework.orm.jpa.JpaTemplate;
import org.springframework.transaction.PlatformTransactionManager;

/**
 * @author Olivier HEDIN / olivier@appspy.org
 */
public abstract class AbstractAppspyJpaJob extends AbstractAppspyJob
{
	public static final String ENTITY_MANAGER_FACTORY = "entityManagerFactory";
	public static final String TRANSACTION_MANAGER = "txManager";
	
	public EntityManagerFactory getEntityManagerFactory(JobExecutionContext jec)
	{
		return (EntityManagerFactory) getBean(jec, ENTITY_MANAGER_FACTORY);
	}
	
	public JpaTemplate getJpaTemplate(JobExecutionContext jec)
	{
		return new JpaTemplate(getEntityManagerFactory(jec));
	}
	
	public PlatformTransactionManager getTransactionManager(JobExecutionContext jec)
	{
		return (PlatformTransactionManager) getBean(jec, TRANSACTION_MANAGER);
	}
}
