/**
 * Copyright (c) 2008 appspy.org, Contributors.
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 *
 * You may obtain a copy of the License at 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the 
 * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language governing permissions 
 * and limitations under the License. */
package org.appspy.admin.jobs;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.appspy.server.bo.scheduler.JobExecution;
import org.appspy.server.bo.scheduler.JobExecutionParam;
import org.quartz.JobExecutionContext;
import org.springframework.beans.factory.BeanFactory;

/**
 * @author Olivier HEDIN / olivier@appspy.org
 */
public abstract class AppspyJobUtils
{
	public static final String BEAN_FACTORY = "beanFactory";
	public static final String JOB_EXECUTION = "jobExecution";
	
	protected static final Log sLog = LogFactory.getLog(AppspyJobUtils.class);
	
	public static JobExecution getJobExecution(JobExecutionContext jec)
	{
		return (JobExecution) jec.get(JOB_EXECUTION);
	}
	
	public static BeanFactory getBeanFactory(JobExecutionContext jec)
	{
		return (BeanFactory) jec.get(BEAN_FACTORY);
	}
	
	public static Object getBean(JobExecutionContext jec, String beanName)
	{
		return getBeanFactory(jec).getBean(beanName);
	}
	
	public static String getJobExecutionParamAsString(JobExecutionContext jec, String paramName)
	{
		for (JobExecutionParam jobExecutionParam : getJobExecution(jec).getParams())
        {
	        if (paramName.equals(jobExecutionParam.getJobScheduleParam().getJobDeclarationParam().getName()))
	        {
	        	return jobExecutionParam.getValue();
	        }
        }
		
		return null;
	}
	
	public static Date getJobExecutionParamAsDate(JobExecutionContext jec, String paramName)
	{
		String valueAsString = getJobExecutionParamAsString(jec, paramName);
		
		Date result = null;
		
		if (valueAsString != null)
		{
			try
            {
	            result = SimpleDateFormat.getDateInstance().parse(valueAsString);
            } catch (ParseException e)
            {
            	sLog.error(e.getMessage(), e);
            }
		}
		
		return result;
	}

	public static Date getJobExecutionParamAsDateTime(JobExecutionContext jec, String paramName)
	{
		String valueAsString = getJobExecutionParamAsString(jec, paramName);
		
		Date result = null;
		
		if (valueAsString != null)
		{
			try
            {
	            result = SimpleDateFormat.getDateTimeInstance().parse(valueAsString);
            } catch (ParseException e)
            {
            	sLog.error(e.getMessage(), e);
            }
		}
		
		return result;
	}
}
