/**
 * Copyright (c) 2008 appspy.org, Contributors.
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 *
 * You may obtain a copy of the License at 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the 
 * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language governing permissions 
 * and limitations under the License. */
package org.appspy.admin.jobs;

import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.PersistenceException;
import javax.persistence.Query;

import org.appspy.admin.service.SchedulingService;
import org.appspy.server.bo.scheduler.JobExecution;
import org.quartz.JobExecutionContext;
import org.quartz.JobExecutionException;
import org.springframework.orm.jpa.JpaCallback;

/**
 * @author Olivier HEDIN / olivier@appspy.org
 */
public class CleanJobExecutions extends AbstractAppspyJpaJob
{
	/*
	 * (non-Javadoc)
	 * 
	 * @see org.quartz.Job#execute(org.quartz.JobExecutionContext)
	 */
	@SuppressWarnings("unchecked")
	public void execute(final JobExecutionContext jec) throws JobExecutionException
	{
		SchedulingService ss = (SchedulingService) getBean(jec, "schedulingService");
		
		List<JobExecution> jobExecutions = getJpaTemplate(jec).executeFind(new JpaCallback(){

			@SuppressWarnings("unchecked")
            public Object doInJpa(EntityManager em) throws PersistenceException
            {
				Query query = em.createQuery("from JobExecution where mStartTime < :date");
				query.setParameter("date", getJobExecutionParamAsDateTime(jec, "date"));
				List<JobExecution> jobExecutions = query.getResultList();
				return jobExecutions;
            }});
		
		for (JobExecution jobExecution : jobExecutions)
		{
			try
			{
				ss.deleteJobExecution(jobExecution);
			}
			catch (Throwable t)
			{
				t.printStackTrace();
			}
		}

	}

}
