/**
 * Copyright (c) 2008 appspy.org, Contributors.
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 *
 * You may obtain a copy of the License at 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the 
 * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language governing permissions 
 * and limitations under the License. */
package org.appspy.admin.jobs;

import javax.persistence.EntityManager;
import javax.persistence.PersistenceException;
import javax.persistence.Query;

import org.appspy.server.bo.scheduler.JobExecutionParam;
import org.quartz.JobExecutionContext;
import org.quartz.JobExecutionException;
import org.springframework.orm.jpa.JpaCallback;
import org.springframework.orm.jpa.JpaTemplate;
import org.springframework.transaction.TransactionStatus;
import org.springframework.transaction.support.TransactionCallbackWithoutResult;
import org.springframework.transaction.support.TransactionTemplate;

/**
 * @author Olivier HEDIN / olivier@appspy.org
 */
public class GenericJpaJob extends AbstractAppspyJpaJob
{

	/* (non-Javadoc)
     * @see org.quartz.Job#execute(org.quartz.JobExecutionContext)
     */
    public void execute(final JobExecutionContext jec) throws JobExecutionException
    {
    	TransactionTemplate tt =new TransactionTemplate(getTransactionManager(jec));
    	tt.execute(new TransactionCallbackWithoutResult(){

			@Override
            protected void doInTransactionWithoutResult(TransactionStatus status)
            {
	            new JpaTemplate(getEntityManagerFactory(jec)).execute(new JpaCallback(){

					public Object doInJpa(EntityManager em) throws PersistenceException
                    {
						String jpaQuery = getJobExecutionParamAsString(jec, "jpaQuery");
						Query query = em.createQuery(jpaQuery);
						for (JobExecutionParam param : getJobExecution(jec).getParams())
                        {
	                        String paramName = param.getJobScheduleParam().getJobDeclarationParam().getName();
	                        if (paramName.equals("jpaQuery"))
	                        {
	                        	continue;
	                        }
	                        String paramChooser = param.getJobScheduleParam().getJobDeclarationParam().getChooser().getChooserAdminClass();
	                        if ("org.appspy.admin.client.paramchooser.DateTimeChooser".equals(paramChooser))
	                        {
	                        	query.setParameter(paramName, getJobExecutionParamAsDateTime(jec, paramName));
	                        }
	                        else if ("org.appspy.admin.client.paramchooser.DateTimeChooser".equals(paramChooser))
	                        {
	                        	query.setParameter(paramName, getJobExecutionParamAsDate(jec, paramName));
	                        }
	                        else
	                        {
	                        	query.setParameter(paramName, getJobExecutionParamAsString(jec, paramName));
	                        }
	                        
                        }
						query.executeUpdate();
						return null;
                    }});
            }});
    }

}
