/*
 * Copyright (c) 2008 appspy.org, Contributors.
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
 * Unless required by applicable law or agreed to in writing, software distributed under the 
 * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language governing permissions 
 * and limitations under the License. */

package org.appspy.admin.service.impl;

import java.io.IOException;
import java.util.Collection;
import java.util.Map;

import org.appspy.admin.service.ReportService;
import org.appspy.server.bo.Dashboard;
import org.appspy.server.bo.Report;
import org.appspy.server.bo.ReportCategory;
import org.appspy.server.bo.ReportParamChooser;
import org.appspy.server.bo.ReportingSystem;
import org.appspy.server.dao.ReportDao;
import org.appspy.server.dao.xml.XmlResourceLoader;
import org.springframework.transaction.PlatformTransactionManager;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

/**
 * @author Olivier HEDIN / olivier@appspy.org
 */
public class ReportServiceImpl implements ReportService {
	
	protected ReportDao mReportDao = null;
	protected PlatformTransactionManager mTransactionManager = null;

	/* (non-Javadoc)
	 * @see org.appspy.admin.service.ReportService#createReportCategory(org.appspy.server.bo.ReportCategory)
	 */
	@Transactional(readOnly=false, propagation=Propagation.REQUIRED)
	public ReportCategory createReportCategory(ReportCategory cat) {
		return mReportDao.saveReportCategory(cat);
	}

	/* (non-Javadoc)
	 * @see org.appspy.admin.service.ReportService#deleteReportCategory(org.appspy.server.bo.ReportCategory)
	 */
	@Transactional(readOnly=false, propagation=Propagation.REQUIRED)
	public void deleteReportCategory(ReportCategory cat) {
		mReportDao.removeReportCategory(cat);
	}

	/* (non-Javadoc)
	 * @see org.appspy.admin.service.ReportService#getReportCategory()
	 */
	public Collection<ReportCategory> getReportCategories() {
		return mReportDao.findAllReportCategories();
	}

	/* (non-Javadoc)
	 * @see org.appspy.admin.service.ReportService#updateReportCategory(org.appspy.server.bo.ReportCategory)
	 */
	@Transactional(readOnly=false, propagation=Propagation.REQUIRED)
	public ReportCategory updateReportCategory(ReportCategory cat) {
		return mReportDao.updateReportCategory(cat);
	}
	
	/* (non-Javadoc)
	 * @see org.appspy.admin.service.ReportService#createReportDescription(org.appspy.server.bo.ReportDescription)
	 */
	@Transactional(readOnly=false, propagation=Propagation.REQUIRED)
	public Report createReport(Report report) {
		return mReportDao.saveReport(report);
	}

	/* (non-Javadoc)
	 * @see org.appspy.admin.service.ReportService#deleteReportDescription(org.appspy.server.bo.ReportDescription)
	 */
	@Transactional(readOnly=false, propagation=Propagation.REQUIRED)
	public void deleteReport(Report report) {
		mReportDao.removeReport(report);
	}

	/* (non-Javadoc)
	 * @see org.appspy.admin.service.ReportService#getReportDescriptions()
	 */
	@Transactional(readOnly=false, propagation=Propagation.REQUIRED)
	public Collection<Report> getReports() {
		return mReportDao.findAllReports();
	}

	/* (non-Javadoc)
	 * @see org.appspy.admin.service.ReportService#updateReportDescription(org.appspy.server.bo.ReportDescription)
	 */
	@Transactional(readOnly=false, propagation=Propagation.REQUIRED)
	public Report updateReport(Report report) {
		return mReportDao.updateReport(report);
	}
	
	/* (non-Javadoc)
	 * @see org.appspy.admin.service.ReportService#findReportDescriptionById()
	 */
	@Transactional(readOnly=false, propagation=Propagation.REQUIRED)
	public Report findReportById(Long reportId) {
		return mReportDao.findReportById(reportId);
	}
	
	/* (non-Javadoc)
	 * @see org.appspy.admin.service.ReportService#createDashboard(org.appspy.server.bo.Dashboard)
	 */
	@Transactional(readOnly=false, propagation=Propagation.REQUIRED)
	public Dashboard createDashboard(Dashboard dashboard) {
		return mReportDao.saveDashboard(dashboard);
	}

	/* (non-Javadoc)
	 * @see org.appspy.admin.service.ReportService#deleteDashboard(org.appspy.server.bo.Dashboard)
	 */
	@Transactional(readOnly=false, propagation=Propagation.REQUIRED)
	public void deleteDashboard(Dashboard dashboard) {
		mReportDao.removeDashboard(dashboard);
	}

	/* (non-Javadoc)
	 * @see org.appspy.admin.service.ReportService#findDashboardById(java.lang.Long)
	 */
	@Transactional(readOnly=false, propagation=Propagation.REQUIRED)
	public Dashboard findDashboardById(Long dashboardId) {
		return mReportDao.findDashboardById(dashboardId);
	}

	/* (non-Javadoc)
	 * @see org.appspy.admin.service.ReportService#getDashboards()
	 */
	@Transactional(readOnly=false, propagation=Propagation.REQUIRED)
	public Collection<Dashboard> getDashboards() {
		return mReportDao.findAllDashboards();
	}

	/* (non-Javadoc)
	 * @see org.appspy.admin.service.ReportService#updateDashboard(org.appspy.server.bo.Dashboard)
	 */
	@Transactional(readOnly=false, propagation=Propagation.REQUIRED)
	public Dashboard updateDashboard(Dashboard dashboard) {
		return mReportDao.updateDashboard(dashboard);
	}

	/* (non-Javadoc)
	 * @see org.appspy.admin.service.ReportService#getReportingSystems()
	 */
	public Collection<ReportingSystem> getReportingSystems() {
		return mReportDao.findAllReportingSystems();
	}
	
	/* (non-Javadoc)
	 * @see org.appspy.admin.service.ReportService#getReportParamChoosers()
	 */
	public Collection<ReportParamChooser> getReportParamChoosers() {
		return mReportDao.findAllReportParamChoosers();
	}
	
	/* (non-Javadoc)
     * @see org.appspy.admin.service.ReportService#importReports(java.util.Collection, java.util.Map)
     */
    public void importReports(Collection<Object> objects, final Map<String, byte[]> resources) throws IOException
    {
    	mReportDao.loadObjects(objects, new XmlResourceLoader(){

			public byte[] loadResource(String name) throws IOException
            {
				return resources.get(name);
            }});
    }

	/**
	 * @return the reportDao
	 */
	public ReportDao getReportDao() {
		return mReportDao;
	}

	/**
	 * @param reportDao the reportDao to set
	 */
	public void setReportDao(ReportDao reportDao) {
		mReportDao = reportDao;
	}

	/**
	 * @return the transactionManager
	 */
	public PlatformTransactionManager getTransactionManager() {
		return mTransactionManager;
	}

	/**
	 * @param transactionManager the transactionManager to set
	 */
	public void setTransactionManager(PlatformTransactionManager transactionManager) {
		mTransactionManager = transactionManager;
	}
}
