/**
 * Copyright (c) 2008 appspy.org, Contributors.
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 *
 * You may obtain a copy of the License at 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the 
 * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language governing permissions 
 * and limitations under the License. */
package org.appspy.admin.service.impl.schedule.params;

import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.HashMap;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.appspy.server.bo.scheduler.JobScheduleParam;


/**
 * @author Olivier HEDIN / olivier@appspy.org
 */
public abstract class AbstractDateParamResolver implements ParamResolver
{
	protected static Log sLog = LogFactory.getLog(AbstractDateParamResolver.class);

	public Date resolveDate(JobScheduleParam jobScheduleParam)
	{
		GregorianCalendar cal = new GregorianCalendar();
		cal.setTime(new Date());
		
		HashMap<String, Integer> fieldMap = new HashMap<String, Integer>();
		fieldMap.put("DATE", Calendar.DATE);
		fieldMap.put("DAY_OF_MONTH", Calendar.DAY_OF_MONTH);
		fieldMap.put("DAY_OF_WEEK", Calendar.DAY_OF_WEEK);
		fieldMap.put("DAY_OF_WEEK_IN_MONTH", Calendar.DAY_OF_WEEK_IN_MONTH);
		fieldMap.put("DAY_OF_YEAR", Calendar.DAY_OF_YEAR);
		fieldMap.put("HOUR", Calendar.HOUR);
		fieldMap.put("HOUR_OF_DAY", Calendar.HOUR_OF_DAY);
		fieldMap.put("MILLISECOND", Calendar.MILLISECOND);
		fieldMap.put("MINUTE", Calendar.MINUTE);
		fieldMap.put("MONTH", Calendar.MONTH);
		fieldMap.put("SECOND", Calendar.SECOND);
		fieldMap.put("WEEK_OF_MONTH", Calendar.WEEK_OF_MONTH);
		fieldMap.put("WEEK_OF_YEAR", Calendar.WEEK_OF_YEAR);
		fieldMap.put("YEAR", Calendar.YEAR);
		
		try
		{
			String[] lines = jobScheduleParam.getValue().split(";");
			for (String line : lines) {
				String[] s = line.split(" ");
				String cmd = s[0];
				String field = s[1].toUpperCase();
				String val = s[2];
				
				if ("set".equalsIgnoreCase(cmd))
				{
					if (fieldMap.containsKey(field))
					{
						cal.set(fieldMap.get(field), Integer.parseInt(val));
					}
				}
				else if ("add".equalsIgnoreCase(cmd))
				{
					if (fieldMap.containsKey(field))
					{
						cal.add(fieldMap.get(field), Integer.parseInt(val));
					}
				}
			}
		}
		catch (Exception ex)
		{
			sLog.error(ex.getMessage(), ex);
		}

		return cal.getTime();
	}

}
