/*
 * Copyright (c) 2008 appspy.org, Contributors.
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
 * Unless required by applicable law or agreed to in writing, software distributed under the 
 * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language governing permissions 
 * and limitations under the License. */

package org.appspy.admin.service.impl.schedule.params;

import java.util.HashMap;
import java.util.Map;

import org.appspy.server.bo.scheduler.JobScheduleParam;

/**
 * @author Olivier HEDIN / olivier@appspy.org
 */
public class ParamResolverFactory {
	
	protected Map<String, ParamResolver> mParamResolvers = new HashMap<String, ParamResolver>();
	protected ParamResolver mDefaultParamResolver = null;
	
	public ParamResolver getParamResolver(JobScheduleParam param)
	{
		ParamResolver result = mDefaultParamResolver;
		
		for (Map.Entry<String, ParamResolver> entry : mParamResolvers.entrySet())
        {
	        if (entry.getKey().equals(param.getJobDeclarationParam().getChooser().getChooserClass()))
	        {
	        	result = entry.getValue();
	        	break;
	        }
        }
		
		return result;
	}

	/**
     * @return the paramResolvers
     */
    public Map<String, ParamResolver> getParamResolvers()
    {
    	return mParamResolvers;
    }

	/**
     * @param paramResolvers the paramResolvers to set
     */
    public void setParamResolvers(Map<String, ParamResolver> paramResolvers)
    {
    	mParamResolvers = paramResolvers;
    }

	/**
     * @return the defaultParamResolver
     */
    public ParamResolver getDefaultParamResolver()
    {
    	return mDefaultParamResolver;
    }

	/**
     * @param defaultParamResolver the defaultParamResolver to set
     */
    public void setDefaultParamResolver(ParamResolver defaultParamResolver)
    {
    	mDefaultParamResolver = defaultParamResolver;
    }
}
